@@ -48,9 +48,9 @@
 // We mean it.
 //
 
-#include "qquickdrawer_p.h"
-#include "qquickpopup_p_p.h"
-#include "qquickvelocitycalculator_p_p.h"
+#include <QtQuickTemplates2/private/qquickdrawer_p.h>
+#include <QtQuickTemplates2/private/qquickpopup_p_p.h>
+#include <QtQuickTemplates2/private/qquickvelocitycalculator_p_p.h>
 
 QT_BEGIN_NAMESPACE
 
@@ -70,6 +70,8 @@ public:
     qreal positionAt(const QPointF &point) const;
 
     void reposition() override;
+    void showOverlay() override;
+    void hideOverlay() override;
     void resizeOverlay() override;
 
     bool startDrag(QEvent *event);
@@ -77,6 +79,7 @@ public:
 #if QT_CONFIG(quicktemplates2_multitouch)
     bool grabTouch(QQuickItem *item, QTouchEvent *event);
 #endif
+    bool blockInput(QQuickItem *item, const QPointF &point) const override;
 
     bool handlePress(QQuickItem* item, const QPointF &point, ulong timestamp) override;
     bool handleMove(QQuickItem* item, const QPointF &point, ulong timestamp) override;
@@ -86,7 +89,7 @@ public:
     bool prepareEnterTransition() override;
     bool prepareExitTransition() override;
 
-    void setEdge(Qt::Edge edge);
+    bool setEdge(Qt::Edge edge);
 
     Qt::Edge edge;
     qreal offset;
